==> NTW_1.0.0.zip: NTW/doc/NTW.R <==
###################################################
### chunk number 1: libPackage
###################################################
#line 106 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpGnCeOg/R.INSTALL65d25d90/NTW/inst/doc/NTW.Rnw"
library(NTW)
library(mvtnorm)


###################################################
### chunk number 2: loadData
###################################################
#line 111 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpGnCeOg/R.INSTALL65d25d90/NTW/inst/doc/NTW.Rnw"
data(sos.data)
X<-sos.data
X<-as.matrix(X)
X


###################################################
### chunk number 3: setPara
###################################################
#line 118 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpGnCeOg/R.INSTALL65d25d90/NTW/inst/doc/NTW.Rnw"
restK=rep(ncol(X)-1, nrow(X))
topD = round(0.6*nrow(X))
topK = round(0.5*nrow(X))
numP = round(0.25*nrow(X))


###################################################
### chunk number 4: genPrior
###################################################
#line 126 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpGnCeOg/R.INSTALL65d25d90/NTW/inst/doc/NTW.Rnw"
pred.net<-matrix(round(runif(nrow(X)*nrow(X), min=0, max=1)), nrow(X), nrow(X))
pred.net


###################################################
### chunk number 5: calResult1
###################################################
#line 131 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpGnCeOg/R.INSTALL65d25d90/NTW/inst/doc/NTW.Rnw"
result<-NTW(X, restK, topD, topK, P.known=NULL, cFlag="sse", pred.net = NULL, sup.drop = -1,numP, noiseLevel=0.1)
result


###################################################
### chunk number 6: calResult2
###################################################
#line 136 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpGnCeOg/R.INSTALL65d25d90/NTW/inst/doc/NTW.Rnw"
result<-NTW(X, restK, topD, topK, P.known=NULL, cFlag="sse", pred.net =pred.net, sup.drop = 1,numP, noiseLevel=0.1)
result


###################################################
### chunk number 7: calResultS
###################################################
#line 155 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpGnCeOg/R.INSTALL65d25d90/NTW/inst/doc/NTW.Rnw"
IX<-P.preestimation(X, topK= round(2*nrow(X)))
result.Srow<-AP.estimation.Srow(r=1,cMM.corrected = 1, pred.net,X, IX,topD, restK, cFlag="sse",sup.drop = -1, numP, noiseLevel=0.1)
result.Srow


###################################################
### chunk number 8: calResultSPKnown
###################################################
#line 164 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpGnCeOg/R.INSTALL65d25d90/NTW/inst/doc/NTW.Rnw"
P.known<-matrix(round(runif(nrow(X)*ncol(X), min=0, max=1)), nrow(X), ncol(X))
result.Srow<-A.estimation.Srow(r=1,cMM.corrected = 1, pred.net, X, P.known, topD, restK, cFlag="ml",sup.drop = -1, noiseLevel=0.1)
result.Srow

==> NTW_1.2.0.zip: NTW/doc/NTW.R <==
###################################################
### chunk number 1: libPackage
###################################################
#line 106 "NTW.Rnw"
library(NTW)
library(mvtnorm)


###################################################
### chunk number 2: loadData
###################################################
#line 111 "NTW.Rnw"
data(sos.data)
X<-sos.data
X<-as.matrix(X)
X


###################################################
### chunk number 3: setPara
###################################################
#line 118 "NTW.Rnw"
restK=rep(ncol(X)-1, nrow(X))
topD = round(0.6*nrow(X))
topK = round(0.5*nrow(X))
numP = round(0.25*nrow(X))


###################################################
### chunk number 4: genPrior
###################################################
#line 126 "NTW.Rnw"
pred.net<-matrix(round(runif(nrow(X)*nrow(X), min=0, max=1)), nrow(X), nrow(X))
pred.net


###################################################
### chunk number 5: calResult1
###################################################
#line 131 "NTW.Rnw"
result<-NTW(X, restK, topD, topK, P.known=NULL, cFlag="sse", pred.net = NULL, sup.drop = -1,numP, noiseLevel=0.1)
result


###################################################
### chunk number 6: calResult2
###################################################
#line 136 "NTW.Rnw"
result<-NTW(X, restK, topD, topK, P.known=NULL, cFlag="sse", pred.net =pred.net, sup.drop = 1,numP, noiseLevel=0.1)
result


###################################################
### chunk number 7: calResultS
###################################################
#line 155 "NTW.Rnw"
IX<-P.preestimation(X, topK= round(2*nrow(X)))
result.Srow<-AP.estimation.Srow(r=1,cMM.corrected = 1, pred.net,X, IX,topD, restK, cFlag="sse",sup.drop = -1, numP, noiseLevel=0.1)
result.Srow


###################################################
### chunk number 8: calResultSPKnown
###################################################
#line 164 "NTW.Rnw"
P.known<-matrix(round(runif(nrow(X)*ncol(X), min=0, max=1)), nrow(X), ncol(X))
result.Srow<-A.estimation.Srow(r=1,cMM.corrected = 1, pred.net, X, P.known, topD, restK, cFlag="ml",sup.drop = -1, noiseLevel=0.1)
result.Srow
